package com.fms.system.mapper;

import java.util.List;
import com.fms.system.domain.Brand;
import com.fms.system.domain.AircraftType;

/**
 * 机型系列Mapper接口
 * 
 * @author Allen
 * @date 2024-05-14
 */
public interface BrandMapper 
{
    /**
     * 查询机型系列
     * 
     * @param brandId 机型系列主键
     * @return 机型系列
     */
    public Brand selectBrandByBrandId(Long brandId);

    /**
     * 查询机型系列列表
     * 
     * @param brand 机型系列
     * @return 机型系列集合
     */
    public List<Brand> selectBrandList(Brand brand);

    /**
     * 新增机型系列
     * 
     * @param brand 机型系列
     * @return 结果
     */
    public int insertBrand(Brand brand);

    /**
     * 修改机型系列
     * 
     * @param brand 机型系列
     * @return 结果
     */
    public int updateBrand(Brand brand);

    /**
     * 删除机型系列
     * 
     * @param brandId 机型系列主键
     * @return 结果
     */
    public int deleteBrandByBrandId(Long brandId);

    /**
     * 批量删除机型系列
     * 
     * @param brandIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBrandByBrandIds(Long[] brandIds);

    /**
     * 批量删除机型
     * 
     * @param brandIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAircraftTypeByBrandIds(Long[] brandIds);
    
    /**
     * 批量新增机型
     * 
     * @param aircraftTypeList 机型列表
     * @return 结果
     */
    public int batchAircraftType(List<AircraftType> aircraftTypeList);
    

    /**
     * 通过机型系列主键删除机型信息
     * 
     * @param brandId 机型系列ID
     * @return 结果
     */
    public int deleteAircraftTypeByBrandId(Long brandId);
}
