package com.fms.system.mapper;

import java.util.List;
import java.util.Map;

import com.fms.system.domain.Failure;
import org.apache.ibatis.annotations.Param;

/**
 * 故障记录Mapper接口
 * 
 * @author Allen
 * @date 2024-05-14
 */
public interface FailureMapper 
{
    /**
     * 查询故障记录
     * 
     * @param id 故障记录主键
     * @return 故障记录
     */
    public Failure selectFailureById(Long id);

    /**
     * 查询故障记录列表
     * 
     * @param failure 故障记录
     * @return 故障记录集合
     */
    public List<Failure> selectFailureList(Failure failure);

    /**
     * 新增故障记录
     * 
     * @param failure 故障记录
     * @return 结果
     */
    public int insertFailure(Failure failure);

    /**
     * 修改故障记录
     * 
     * @param failure 故障记录
     * @return 结果
     */
    public int updateFailure(Failure failure);

    /**
     * 删除故障记录
     * 
     * @param id 故障记录主键
     * @return 结果
     */
    public int deleteFailureById(Long id);

    /**
     * 批量删除故障记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFailureByIds(Long[] ids);

    Integer getMajorCount(@Param("reportMonth") String reportMonth, @Param("major") String major);

    List<String> getTop5UnserviceableCompName(@Param("reportMonth") String reportMonth, @Param("major") String major);

    Integer getFailureCount(@Param("reportMonth") String reportMonth, @Param("compName") String compName, @Param("major") String major);

    List<String> getFailureDescription(@Param("reportMonth") String reportMonth, @Param("compName") String compName, @Param("major") String major);

    List<String> getFailureCause(@Param("reportMonth") String reportMonth, @Param("compName") String compName, @Param("major") String major);

    List<String> getFailureCompType(@Param("reportMonth") String reportMonth, @Param("compName") String compName, @Param("major") String major);

    List<Map> getMajorOption();
}
